// clogconv.cpp
//
// Copyright (C) 2000 Robert Barron, KA5WSS
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include <stdio.h>
#if !defined(LC_GUI) || !defined(LC_NT)
#include <string.h>
#endif

#include "adiffile.h"
#include "arrlfile.h"
#include "ctfile.h"
#include "ct8file.h"
#include "ct9file.h"
#include "dbfile.h"
#include "dxclus.h"
#include "dxifile.h"
#include "logconv.h"
#include "nafile.h"
#include "na9file.h"
#include "cabfile.h"
#include "sdffile.h"
#include "trfile.h"
#include "wrtc.h"

#define STRING_BUFFER_SIZE    2048

static void ShowOptions();

#if defined(LC_NT)
    static char *exeName = "clogconv";        // Win32 console
#else
  #ifdef LC_LINUX
    static char *exeName = "logconv";         // Linux
  #else
    static char *exeName = "dlogconv";        // DOS
  #endif
#endif

int main(int argc, char *argv[])
{
    char lpCmdLine[STRING_BUFFER_SIZE];
    boolean bVerboseMode = FALSE;
	RLogConv	convObj;

    qso_data qso;

    printf("Amateur Radio Log File Conversion v1.70\n\r(c) 2000 by KA5WSS\n\r\n\r");

    if (argc < 3)
    {
        if ((argc == 2) && (stricmp("-h", argv[1]) == 0))
            ShowOptions();
        else
        {
            printf("usage: %s infile outfile [options]\n\r", exeName);
            printf("\n\rFor a complete list of options type in \'%s -h\'\n\r", exeName);
        }
        return(1);
    }
    
    *lpCmdLine = (char)NULL;
    for (int c = 3; c < argc; c++)     // Turn command line arguments into a string
    {                                   // Similar to Windows.
        strcat(lpCmdLine, argv[c]);
        strcat(lpCmdLine, " ");
    }

	convObj.setFileOptions(lpCmdLine);

	int FileType;
	if (!convObj.setInputFile(argv[1], &FileType))
	{
		printf("Error opening input file %s", argv[1]);
		return -1;
	}

	if (!convObj.setOutputFile(argv[2]))
	{
		printf("Error opening output file %s", argv[2]);
		return -1;
	}


	if (strstr(lpCmdLine, "-v") != NULL)
		bVerboseMode = TRUE;

	int nQSONumber;
	int nPosition;
	float fPercentComplete;
	int nInputFileSize = convObj.getInputByteSize();

	while (convObj.convertNextQso(&nPosition, &nQSONumber) > 0)
	{
		fPercentComplete = (((float)nPosition / (float)nInputFileSize) * (float)100);
		if (bVerboseMode)
			printf("%d\n", nQSONumber);
	}

	printf("Conversion Complete!\n\rProcessed %d QSO's\n\r", nQSONumber);
               
    return 0;
}

static void ShowOptions()
{
    printf("usage: %s infile outfile [options]\n\r\n\r", exeName);
    printf("  -bNumeric    Output the BAND field in meters (dBase output only).\n\r"); 
    printf("  -c<contest>  Indicate the contest type for logs that do not contain header\n\r");
    printf("               information (ARRL .log).  See readme.txt for the list of values.\n\r");
    printf("  -freq        Add new output field which contains the exact frequency, in MHz\n\r");
    printf("               (dBase output only).\n\r");
    printf("  -h           Displays this list of options (Command Line only).\n\r");
    printf("  -n \"Comment\" Indicate string to be placed in notes field, if applicable.\n\r");
    printf("  -qsonum      Add field which sequentially numbers QSO's (dBase output only).\n\r");
    printf("  -tApproach   Append \'TM9\' to TIME field for Approach support\n\r");
    printf("               (dBase output only).\n\r");
    printf("  -v           Verbose output.  Will indicate the QSO number being converted\n\r");
    printf("               (Command Line only).\n\r");
	printf("\n\rFor updates, check http://www.qsl.net/ka5wss/logconv/\n\r");
    return;
}


